"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.print_diff_from_files = exports.print_diff = void 0;
const fs = require('fs');
const git_diff_1 = require("./git-diff");
const jest_info_1 = require("./jest-info");
function print_diff(gDiff = null, ignore = [], flat = false) {
    return __awaiter(this, void 0, void 0, function* () {
        if (gDiff === null) {
            throw "error no git diff provided";
        }
        const files = (0, git_diff_1.specFilesChanged)(gDiff, ignore);
        print_diff_from_files(files, flat);
    });
}
exports.print_diff = print_diff;
function print_diff_from_files(files, flat, gDiff = undefined) {
    if (files === undefined || !files.length) {
        return console.error('No test files changes');
    }
    let changesPrinted = false;
    files.forEach((filename) => {
        const linesChanged = (gDiff) ? (0, git_diff_1.linesFromGitDiff)(gDiff, filename) : null;
        const specFile = fs.readFileSync(filename, 'utf8');
        const { tree, doc, flatDoc } = (0, jest_info_1.descriptionFromSpecFile)(specFile, linesChanged);
        if (tree.length > 0) {
            flat ? console.log(flatDoc) : console.log(doc);
            changesPrinted = true;
        }
    });
    if (!changesPrinted) {
        console.log('No changes to print');
    }
}
exports.print_diff_from_files = print_diff_from_files;
